==> lms-1.4.5+libs.tar.gz: lms/lib/checkip.php <==
<?php

/*
 * LMS version 1.4.5 Persus
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: checkip.php,v 1.16.2.2 2005/01/01 19:19:23 alec Exp $
 */

// Sprawdzenie czy poczenie z dozwolonego IP.

if($_CONFIG['phpui']['allow_from'])
{
	// usumy prefix ipv6 jak jest
	
	$ipaddr = str_replace('::ffff:','',$_SERVER['REMOTE_ADDR']);

	$allowedlist = explode(',',$_CONFIG['phpui']['allow_from']);

	foreach($allowedlist as $value)
	{
		list($net,$mask) = split('/',$value);
		$net=trim($net);
		$mask=trim($mask);
		if($mask == '')
			$mask = '32';
		if($mask >= 0 || $mask <= 32)
			$mask = prefix2mask($mask);
	
		if(isipinstrict($ipaddr,$net,$mask))
			$isin = TRUE;
	}

	if(!$isin)
	{
		header('HTTP/1.1 403 Forbidden');
		echo '<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
		<HTML><HEAD>
		<TITLE>403 Forbidden</TITLE>
		</HEAD><BODY>
		<H1>Forbidden</H1>
		You don\'t have permission to access '.$_SERVER['REQUEST_URI'].'
		on this server.<P>
		<HR>
		'.$_SERVER['SERVER_SIGNATURE'].'
		</BODY></HTML>
		';
		exit(0);
	}
}

?>

==> lms-1.6.1+libs.tar.gz: lms/lib/checkip.php <==
<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: checkip.php,v 1.20.2.1 2005/05/13 20:09:53 alec Exp $
 */

// Checking if connection is from allowed IP

if(isset($_CONFIG['phpui']['allow_from']))
{
	// usumy prefix ipv6 jak jest
	
	$ipaddr = str_replace('::ffff:','',$_SERVER['REMOTE_ADDR']);

	$allowedlist = explode(',',$_CONFIG['phpui']['allow_from']);

	foreach($allowedlist as $value)
	{
		list($net,$mask) = sscanf($value, '%[^/]/%[0-9]');
		$net=trim($net);
		$mask=trim($mask);
		if($mask == '')
			$mask = '32';
		if($mask >= 0 || $mask <= 32)
			$mask = prefix2mask($mask);
	
		if(isipinstrict($ipaddr,$net,$mask))
			$isin = TRUE;
	}

	if(!$isin)
	{
		header('HTTP/1.1 403 Forbidden');
		echo '<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
		<HTML><HEAD>
		<TITLE>403 Forbidden</TITLE>
		</HEAD><BODY>
		<H1>Forbidden</H1>
		You don\'t have permission to access '.$_SERVER['REQUEST_URI'].'
		on this server.<P>
		<HR>
		'.$_SERVER['SERVER_SIGNATURE'].'
		</BODY></HTML>
		';
		exit(0);
	}
}

?>
